@@ -7,6 +7,11 @@ Licence: Apache-2.0
 import numpy as np
 import tensorflow as tf
 
+__author__ = 'Sanjaya Lohani'
+__email__ = 'slohani@mlphys.com'
+__licence__ = 'Apache 2.0'
+__website__ = "sanjayalohani.com"
+
 
 class PredictDensityMatrix(tf.keras.layers.Layer):
     def __init__(self, name='Density_matrix', qubit_size=2, **kwargs):
