@@ -5,6 +5,10 @@ Licence: Apache-2.0
 """
 import tensorflow as tf
 
+__author__ = 'Sanjaya Lohani'
+__email__ = 'slohani@mlphys.com'
+__licence__ = 'Apache 2.0'
+__website__ = "sanjayalohani.com"
 
 def max_eigen(dm_tensor):
     eigv, _ = tf.linalg.eigh(dm_tensor)
