@@ -4,9 +4,12 @@ email: slohani@mlphys_nightly.com
 Licence: Apache-2.0
 """
 import numpy as np
-
 import mlphys.deepqis.utils.gen_basis_order as gen_basis_order
 
+__author__ = 'Sanjaya Lohani'
+__email__ = 'slohani@mlphys.com'
+__licence__ = 'Apache 2.0'
+__website__ = "sanjayalohani.com"
 
 class MultiQubitSystem:
 
